@@ -5,7 +5,7 @@ use strict;
 use warnings;
 ##use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Common configuration handling
-our $VERSION = '3.20221006'; # VERSION
+our $VERSION = '3.20221121'; # VERSION
 use English;
 use JSON::XS;
 use TOML;
@@ -32,6 +32,8 @@ sub default_config {
         'dryrun'                          => 0,
         'logtoerr'                        => 0,
         'error_log'                       => '/var/log/authentication_milter.err',
+        'extended_log'                    => 1,
+        'legacy_log'                      => 0,
         'connection'                      => 'inet:12345@localhost',
         'umask'                           => '0000',
         'runas'                           => 'nobody',
@@ -265,7 +267,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 3.20221006
+version 3.20221121
 
 =head1 SYNOPSIS
 
